o3
==

All functions in this module are accessible via the ``o3`` submodule:

.. jupyter-execute::

    from e3nn import o3

    R = o3.rand_matrix(10)
    D = o3.Irreps.spherical_harmonics(4).D_from_matrix(R)

.. rubric:: Overview

.. toctree::
    :maxdepth: 1

    o3_rotation
    o3_irreps
    o3_tp
    o3_sh
    o3_reduce
    o3_s2grid
    o3_wigner
